@@ -37,12 +37,12 @@ NULL
 #' Individualized cost-effectiveness analysis
 #'
 #' Conduct individualized cost-effectiveness analysis (ICEA) given output of an economic
-#' model. That is, summarize a probabilistic sensitivity analysis (PSA) by subgroup.
+#' model; that is, summarize a probabilistic sensitivity analysis (PSA) by subgroup.
 #' \itemize{
-#'  \item \code{icea()} computes the probability that
+#'  \item [icea()] computes the probability that
 #' each treatment is most cost-effective, output for a cost-effectiveness acceptability frontier,
 #' the expected value of perfect information, and the net monetary benefit for each treatment.
-#' \item \code{icea_pw()} conducts pairwise ICEA by comparing strategies to a comparator. Computed
+#' \item [icea_pw()] conducts pairwise ICEA by comparing strategies to a comparator. Computed
 #' quantities include the incremental cost-effectiveness ratio, the 
 #' incremental net monetary benefit, output for a cost-effectiveness plane,
 #' and output for a cost-effectiveness acceptability curve.
@@ -50,27 +50,27 @@ NULL
 #'  
 #'
 #' @param x An object of simulation output characterizing the probability distribution
-#' of clinical effectiveness and costs. If the default method is used, then \code{x}
-#' must be a \code{data.frame} or \code{data.table} containing columns of
+#' of clinical effectiveness and costs. If the default method is used, then `x`
+#' must be a `data.frame` or `data.table` containing columns of
 #' mean costs and clinical effectiveness where each row denotes a randomly sampled parameter set
 #' and treatment strategy.
 #' @param k Vector of willingness to pay values.
-#' @param comparator Name of the comparator strategy in x.
-#' @param sample Character name of column from \code{x} denoting a randomly sampled parameter set.
-#' @param strategy Character name of column from \code{x} denoting treatment strategy.
-#' @param grp Character name of column from \code{x} denoting subgroup. If \code{NULL}, then
+#' @param comparator Name of the comparator strategy in `x`.
+#' @param sample Character name of column from `x` denoting a randomly sampled parameter set.
+#' @param strategy Character name of column from `x` denoting treatment strategy.
+#' @param grp Character name of column from `x` denoting subgroup. If `NULL`, then
 #' it is assumed that there is only one group.
-#' @param e Character name of column from \code{x} denoting clinical effectiveness.
-#' @param c Character name of column from \code{x} denoting costs.
+#' @param e Character name of column from `x` denoting clinical effectiveness.
+#' @param c Character name of column from `x` denoting costs.
 #' @param ... Further arguments passed to or from other methods. Currently unused.
-#' @return \code{icea} returns a list containing four \code{data.table}s:
+#' @return [icea()] returns a list of four `data.table` elements.
 #' 
 #' \describe{
-#'   \item{summary}{A \code{data.table} of the mean, 2.5\% quantile, and 97.5\% 
+#'   \item{summary}{A `data.table` of the mean, 2.5% quantile, and 97.5% 
 #'   quantile by strategy and group for clinical effectiveness and costs.}
 #'   \item{mce}{The probability that each strategy is the most effective treatment
 #'   for each group for the range of specified willingness to pay values. In addition,
-#'   the column \code{best} denotes the optimal strategy (i.e., the strategy with the
+#'   the column `best` denotes the optimal strategy (i.e., the strategy with the
 #'   highest expected net monetary benefit), which can be used to plot the 
 #'   cost-effectiveness acceptability frontier (CEAF).}
 #'   \item{evpi}{The expected value of perfect information (EVPI) by group for the range
@@ -78,20 +78,20 @@ NULL
 #'   monetary benefit given current information (i.e., the strategy with the highest
 #'   expected net monetary benefit) from the expected net monetary benefit given
 #'   perfect information.}
-#'    \item{nmb}{The mean, 2.5\% quantile, and 97.5\% quantile of net monetary benefits
+#'    \item{nmb}{The mean, 2.5% quantile, and 97.5% quantile of net monetary benefits
 #'    for the range of specified willingness to pay values.}
 #' }
 #' 
-#' \code{icea_pw} also returns a list containing four data.tables:
+#' \code{icea_pw} also returns a list of four `data.table` elements:
 #'  \describe{
-#'   \item{summary}{A data.table of the mean, 2.5\% quantile, and 97.5\% 
+#'   \item{summary}{A data.table of the mean, 2.5% quantile, and 97.5% 
 #'   quantile by strategy and group for clinical effectiveness and costs.}
 #'   \item{delta}{Incremental effectiveness and incremental cost for each simulated
 #'   parameter set by strategy and group. Can be used to plot a cost-effectiveness plane. }
 #'   \item{ceac}{Values needed to plot a cost-effectiveness acceptability curve by
 #'   group. The CEAC plots the probability that each strategy is more cost-effective than
 #'   the comparator for the specified willingness to pay values.}
-#'    \item{inmb}{The mean, 2.5\% quantile, and 97.5\% quantile of
+#'    \item{inmb}{The mean, 2.5% quantile, and 97.5% quantile of
 #'    incremental net monetary benefits for the range of specified willingness to pay values.}
 #' }
 #' @name icea
@@ -238,10 +238,10 @@ icea_pw.default <- function(x, k = seq(0, 200000, 500), comparator,
 icea.ce <- function(x, k = seq(0, 200000, 500), dr_qalys, dr_costs, ...){
   category <- dr <- NULL
   sim <- cbind(x$costs[category == "total" & dr == dr_costs,
-                       c("sample", "strategy_id", "costs")],
+                       c("sample", "strategy_id", "grp_id", "costs")],
                x$qalys[dr == dr_qalys, "qalys", with = FALSE])
   res <- icea(sim, k = k, sample = "sample", strategy = "strategy_id",
-              e = "qalys", c = "costs")
+              grp = "grp_id", e = "qalys", c = "costs")
   return(res)
 }
 
@@ -250,10 +250,10 @@ icea.ce <- function(x, k = seq(0, 200000, 500), dr_qalys, dr_costs, ...){
 icea_pw.ce <- function(x, k = seq(0, 200000, 500), comparator, dr_qalys, dr_costs, ...){
   category <- dr <- NULL
   sim <- cbind(x$costs[category == "total" & dr == dr_costs,
-                       c("sample", "strategy_id", "costs")],
+                       c("sample", "strategy_id", "grp_id", "costs")],
                x$qalys[dr == dr_qalys, "qalys", with = FALSE])
   res <- icea_pw(sim, k = k, comparator = comparator, sample = "sample",
-                 strategy = "strategy_id",
+                 strategy = "strategy_id", grp = "grp_id",
                  e = "qalys", c = "costs")
   return(res)
 }
@@ -378,26 +378,26 @@ format_cri <- function(est, lower, upper, costs = TRUE, digits){
 #' ICER table
 #'
 #' Generate a table of incremental cost-effectiveness ratios given output from 
-#' \code{\link{icea_pw}}.
+#' [icea_pw()].
 #'
-#' @param x An object of class "icea_pw" returned by \code{\link{icea_pw}}.
+#' @param x An object of class `icea_pw` returned by [icea_pw()].
 #' @param k Willingness to pay.
-#' @param cri If \code{TRUE}, credible intervals are computed; otherwise 
+#' @param cri If `TRUE`, credible intervals are computed; otherwise 
 #' they are not.
-#' @param prob A numeric scalar in the interval \code{(0,1)} giving the credible interval.
+#' @param prob A numeric scalar in the interval `(0,1)` giving the credible interval.
 #' Default is 0.95 for a 95 percent credible interval. 
 #' @param digits_qalys Number of digits to use to report QALYs.
 #' @param digits_costs Number of digits to use to report costs.
-#' @param output Should output be a \code{data.table} or a list of matrices for
+#' @param output Should output be a `data.table` or a list of matrices for
 #' each group.
-#' @param rownames Row names for matrices when \code{output = "matrix"}.
-#' @param colnames Column names for matrices when \code{output = "matrix"}.
-#' @param drop If \code{TRUE}, then the result is coerced to the lowest possible dimension. 
-#' Relevant if \code{output = "matrix"} and there is one group, in which case a single
-#' matrix will be returned if \code{drop = TRUE} and a list of length 1 will be returned
-#' if \code{drop = FALSE}.
-#' @seealso \code{\link{icea_pw}}
-#' @return If \code{output = "matrix"}, then a list of matrices (or a matrix if
+#' @param rownames Row names for matrices when `output = "matrix"`.
+#' @param colnames Column names for matrices when `output = "matrix"`.
+#' @param drop If `TRUE`, then the result is coerced to the lowest possible dimension. 
+#' Relevant if `output = "matrix"` and there is one group, in which case a single
+#' matrix will be returned if `drop = TRUE` and a list of length 1 will be returned
+#' if `drop = FALSE`.
+#' @seealso [icea_pw()]
+#' @return If `output = "matrix"`, then a list of matrices (or a matrix if
 #' \code{drop = TRUE}) reporting incremental cost-effectiveness ratios (ICERs)
 #' by group. Specifically, each matrix contains five rows for: (i) 
 #' incremental quality-adjusted life-years (QALYs), (ii) incremental costs,
@@ -406,7 +406,7 @@ format_cri <- function(est, lower, upper, costs = TRUE, digits){
 #'  to a comparator. The number of columns is equal to the
 #' number of strategies (including the comparator).
 #' 
-#' If \code{output = "data.table"}, then the results are reported as a \code{data.table},
+#' If `output = "data.table"`, then the results are reported as a `data.table`,
 #' with one row for each strategy and group combination.
 #' @export
 icer_tbl <- function(x, k = 50000, cri = TRUE, prob = 0.95, 
